#! /bin/sh
#
#  ProQueSys Unix product install/uninstall custom step
#  (C) COPYRIGHT HELP SYSTEMS, LLC  2013

DBSIZE=medium
CONFILENAME=netsaw.conf
DATASUBDIR=SESSIONDB
BINDIR=$2
DATADIR=$BINDIR/$DATASUBDIR


do_installimextension ()
{
    intermapper_extension "--install" "netsaw.jar" "netsaw.xml"
    RETVAL=$?
    if [ $RETVAL != 0 ]
    then
        echo "Intermapper extension installer exited with code $RETVAL"
    fi
    return 0
}



do_uninstallimextension ()
{
    intermapper_extension "--uninstall" "netsaw.jar" "netsaw.xml"
    RETVAL=$?
    if [ $RETVAL != 0 ]
    then
        echo "Intermapper extension un-installer exited with code $RETVAL"
    fi
    return 0
}

#
#  This is intermapper_extension.sh from Bill/DartWare
#
intermapper_extension ()
{
        im_cmd=""
        case `uname -s` in
                Linux )   im_cmd="/etc/init.d/intermapperd" ;;
                Darwin )  im_cmd="/usr/local/share/intermapper/Extension.sh" ;;
                SunOS )   im_cmd="/etc/init.d/intermapperd" ;;
                * )       exit 111 ;;
        esac
        if [ -x "$im_cmd" ]; then
                "$im_cmd" "$@"
                return $?
        fi
        return 110
}
#  End of intermapper_extension.sh from DartWare



# Configuration is program specific
do_configure ()
{
    echo "*** Configuring service ..."
    CONFILE=$BINDIR/$CONFILENAME
    DATADIR=$BINDIR/$DATASUBDIR
    if [ -f $CONFILE ]
    then
        echo "Existing configuration file found, using that [$CONFILE]"
    else
        echo "Session database directory [$DATADIR]: "
        read USERDATADIR
        if [ -n "$USERDATADIR" ]
        then
            DATADIR=$USERDATADIR
        fi
        echo "Using $DATADIR for sessions database"
        echo "Select an initial database size [medium]"
        echo "(note: this can be changed from the configuration window later):"
        echo "  (0)  tiny          3000 sessions         ~400 KB"
        echo "  (1)  small         8 million sessions    ~1000 MB"
        echo "  (2)  medium        80 million sessions   ~10 GB"
        echo "  (3)  large         800 million sessions  ~100 GB"
        echo "  (4)  verylarge     2 billion sessions    ~256 GB"
        echo "Initial size [2]: "
        read PREFDBSIZE
        case $PREFDBSIZE in
            "0")    DBSIZE="tiny";;
            "1")    DBSIZE="small";;
            "2")    DBSIZE="medium";;
            "3")    DBSIZE="large";;
            "4")    DBSIZE="verylarge";;
            "")     ;;
              *)    echo "Unknown database size, selecting default ... "
        esac
        echo "Database size: $DBSIZE"
        mkdir -p $DATADIR || exit 4
        echo "#" > ${CONFILE}
        echo "#  Automatically generated configuration file" >> ${CONFILE}
        echo "#  (C) COPYRIGHT HELP SYSTEMS, LLC  2013" >> ${CONFILE}
        echo "#" >> ${CONFILE}
        echo "querythreads 3" >> ${CONFILE}
        echo "logfile netsaw2.log" >> ${CONFILE}
        echo "<sessiontables>" >> ${CONFILE}
        echo "    conntracksize 20971" >> ${CONFILE}
        echo "    memcachesize 2097152" >> ${CONFILE}
        echo "</sessiontables>" >> ${CONFILE}
        echo "<netflow>" >> ${CONFILE}
        echo "    netflowport 2055" >> ${CONFILE}
        echo "</netflow>" >> ${CONFILE}
        echo "<sflow>" >> ${CONFILE}
        echo "    sflowport 6343" >> ${CONFILE}
        echo "</sflow>" >> ${CONFILE}
        echo "<storage>" >> ${CONFILE}
        echo "    storageinterval 60" >> ${CONFILE}
        echo "    databasepath ${DATADIR}" >> ${CONFILE}
        echo "    prefdatabasesize ${DBSIZE}" >> ${CONFILE}
        echo "</storage>" >> ${CONFILE}
    fi
    return 0
}



if [ "$1" = "install" ]
then
    do_configure
    if [ -f "netsaw.jar" ]
    then
        do_installimextension
    fi 
    exit 0
fi

if [ "$1" = "uninstall" ]
then
    if [ -f "netsaw.jar" ]
    then
        do_uninstallimextension
    fi
    exit 0
fi

echo "This script is part of a custom installer system.  Please do not call it directly."
exit 1

